.. image:: http://img.shields.io/pypi/v/nagiosplugin-stubs.svg
    :target: https://pypi.org/project/nagiosplugin-stubs
    :alt: This package on the Python Package Index

.. image:: https://github.com/Josef-Friedrich/nagiosplugin-stubs/actions/workflows/tests.yml/badge.svg
    :target: https://github.com/Josef-Friedrich/nagiosplugin-stubs/actions/workflows/tests.yml
    :alt: Tests

nagiosplugin-stubs
==================

Type stubs for the `nagiosplugin <https://github.com/mpounsett/nagiosplugin>`_ package.

Other stub packages

* https://github.com/lxml/lxml-stubs
* https://github.com/tk0miya/docutils-stubs
